@@ -7,8 +7,8 @@ use autodie qw(:all);
 use IPC::System::Simple;
 
 use Moo;
+use Boxer::Types qw( DataDir ClassDir NodeDir Suite );
 use Types::Standard qw( Str Undef );
-use Types::Path::Tiny qw( Dir );
 extends 'Boxer::Task';
 
 use File::BaseDir qw(data_dirs);
@@ -18,7 +18,7 @@ use YAML::XS;
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = '0.004';
+our $VERSION   = 'v1.0.0';
 
 # permit callers to sloppily pass undefined values
 sub BUILDARGS
@@ -30,31 +30,32 @@ sub BUILDARGS
 
 has datadir => (
 	is       => 'lazy',
-	isa      => Dir,
-	coerce   => Dir->coercion,
+	isa      => DataDir,
+	coerce   => 1,
 	required => 1,
 	default  => sub { scalar( data_dirs( 'boxer', $_[0]->suite ) ) },
 );
 
 has suite => (
 	is       => 'ro',
-	isa      => Str,
+	isa      => Suite,
 	required => 1,
+	coerce   => 1,
 	default  => sub {'wheezy'},
 );
 
 has classdir => (
 	is       => 'lazy',
-	isa      => Dir,
-	coerce   => Dir->coercion,
+	isa      => ClassDir,
+	coerce   => 1,
 	required => 1,
 	default  => sub { $_[0]->datadir->child('classes') },
 );
 
 has nodedir => (
 	is       => 'lazy',
-	isa      => Dir,
-	coerce   => Dir->coercion,
+	isa      => NodeDir,
+	coerce   => 1,
 	required => 1,
 	default  => sub { $_[0]->datadir ? $_[0]->datadir->child('nodes') : '.' },
 );
